## Bootstrap Conversion Progress

Use this table to list the php pages that have been converted to bootstrap, those that have yet to be converted, and those that are currently being worked on.

The script used to generate the table can be found at the bottom of this page

Use the &#x2705; emoji (`&#x2705;`) to show that the bootstrap conversion is complete
Use the &#x1f504; emoji (`&#x1f504;`) to show that the bootstrap conversion is in progress

The table can be generated by running this bash script on the directory in which the php files are located. e.g.:

````bash
   mktable.sh pfsense-bootstrap/usr/local/www
````

You can then copy/paste the script output into this file. (Is that recursive?)

````bash
#!/bin/bash
# mktable.sh

# Generate a table in GitHub markdown showing each php file and whether it has been converted to bootstrap yet
# $1 = path to pfSense usr/local/www directory
# Completed files are assumed to have foot.inc included

COMPLETED=' &#x2705;'
INPROGRESS=' &#x1f504;'
pushd $1

printf "|%-45s|%-25s|%-24s|%-60s|\n" "Page/file" "Status" "User" "Comments"
printf "|---------------------------------------------|:-------------------------:|------------------------|------------------------------------------------------------|\n"

FILES=$(ls -1 *.php)

for F in $FILES ; do
   printf "|%-45s|" $F

   if(grep foot.inc $F >/dev/null 2>&1 ) ; then
      printf "%-25s" "$COMPLETED"
   else
      printf "%25s" "                  "
   fi

   printf "|%24s|%60s|\n" " " " "

done

popd

````
### PHP file status
|Page/file                                    |Status                   |User                    |Comments                                                    |
|---------------------------------------------|:-------------------------:|------------------------|------------------------------------------------------------|
|bandwidth_by_ip.php                          |                         |                        |                                                            |
|carp_status.php                              | &#x2705;                |                        |                                                            |
|crash_reporter.php                           | &#x2705;                |                        |                                                            |
|diag_arp.php                                 | &#x2705;                |                        |                                                            |
|diag_authentication.php                      | &#x2705;                |                        |                                                            |
|diag_backup.php                              | &#x2705;                |                        |                                                            |
|diag_confbak.php                             | &#x2705;                |                        |                                                            |
|diag_defaults.php                            | &#x2705;                |                        |                                                            |
|diag_dns.php                                 | &#x2705;                |                        |                                                            |
|diag_dump_states.php                         | &#x2705;                |                        |                                                            |
|diag_dump_states_sources.php                 | &#x2705;                |                        |                                                            |
|diag_gmirror.php                             |                         |                        |                                                            |
|diag_ipsec_leases.php                        | &#x2705;                |                        |                                                            |
|diag_ipsec.php                               |                         |                        |                                                            |
|diag_ipsec_sad.php                           | &#x2705;                |                        |                                                            |
|diag_ipsec_spd.php                           | &#x2705;                |                        |                                                            |
|diag_ipsec_xml.php                           |                         |                        |                                                            |
|diag_limiter_info.php                        | &#x2705;                |                        |                                                            |
|diag_logs_filter_dynamic.php                 | &#x2705;                |                        |                                                            |
|diag_logs_filter.php                         | &#x2705;                |                        |                                                            |
|diag_logs_filter_summary.php                 | &#x2705;                |                        |                                                            |
|diag_logs.php                                | &#x2705;                |                        |                                                            |
|diag_logs_settings.php                       | &#x2705;                |                        |                                                            |
|diag_logs_vpn.php                            | &#x2705;                |                        |                                                            |
|diag_nanobsd.php                             | &#x2705;                |                        |                                                            |
|diag_ndp.php                                 | &#x2705;                |                        |                                                            |
|diag_packet_capture.php                      | &#x2705;                |                        |                                                            |
|diag_patterns.php                            | &#x2705;                |                        |                                                            |
|diag_pf_info.php                             | &#x2705;                |                        |                                                            |
|diag_ping.php                                | &#x2705;                |                        |                                                            |
|diag_pkglogs.php                             | &#x2705;                |                        |                                                            |
|diag_resetstate.php                          | &#x2705;                |                        |                                                            |
|diag_routes.php                              | &#x2705;                |                        |                                                            |
|diag_smart.php                               | &#x2705;                |                        |                                                            |
|diag_sockets.php                             | &#x2705;                |                        |                                                            |
|diag_states_summary.php                      | &#x2705;                |                        |                                                            |
|diag_system_activity.php                     | &#x2705;                |                        |                                                            |
|diag_system_pftop.php                        | &#x2705;                |                        |                                                            |
|diag_tables.php                              | &#x2705;                |                        |                                                            |
|diag_testport.php                            | &#x2705;                |                        |                                                            |
|diag_traceroute.php                          | &#x2705;                |                        |                                                            |
|easyrule.php                                 |                         |                        |                                                            |
|edit.php                                     | &#x2705;                |                        |                                                            |
|exec.php                                     | &#x2705;                |                        |                                                            |
|firewall_aliases_edit.php                    | &#x2705;                |                        |                                                            |
|firewall_aliases_import.php                  | &#x2705;                |                        |                                                            |
|firewall_aliases.php                         | &#x2705;                |                        |                                                            |
|firewall_nat_1to1_edit.php                   |                         |                        |                                                            |
|firewall_nat_1to1.php                        |                         |                        |                                                            |
|firewall_nat_edit.php                        |                         |                        |                                                            |
|firewall_nat_npt_edit.php                    | &#x2705;                |                        |                                                            |
|firewall_nat_npt.php                         | &#x2705;                |                        |                                                            |
|firewall_nat_out_edit.php                    |                         |                        |                                                            |
|firewall_nat_out.php                         |                         |                        |                                                            |
|firewall_nat.php                             |                         |                        |                                                            |
|firewall_rules_edit.php                      | &#x2705;                |                        |                                                            |
|firewall_rules.php                           | &#x2705;                |                        |                                                            |
|firewall_schedule_edit.php                   |                         |                        |                                                            |
|firewall_schedule.php                        | &#x2705;                |                        |                                                            |
|firewall_shaper_layer7.php                   |                         |                        |                                                            |
|firewall_shaper.php                          |                         |                        |                                                            |
|firewall_shaper_queues.php                   |                         |                        |                                                            |
|firewall_shaper_vinterface.php               |                         |                        |                                                            |
|firewall_shaper_wizards.php                  | &#x2705;                |                        |                                                            |
|firewall_virtual_ip_edit.php                 | &#x2705;                |                        |                                                            |
|firewall_virtual_ip.php                      | &#x2705;                |                        |                                                            |
|getserviceproviders.php                      |                         |                        |                                                            |
|getstats.php                                 |                         |                        |                                                            |
|graph_cpu.php                                |                         |                        |                                                            |
|graph.php                                    |                         |                        |                                                            |
|halt.php                                     | &#x2705;                |                        |                                                            |
|help.php                                     |                         |                        |                                                            |
|ifstats.php                                  |                         |                        |                                                            |
|index.php                                    | &#x2705;                |                        |                                                            |
|interfaces_assign.php                        | &#x2705;                |                        |                                                            |
|interfaces_bridge_edit.php                   | &#x2705;                |                        |                                                            |
|interfaces_bridge.php                        | &#x2705;                |                        |                                                            |
|interfaces_gif_edit.php                      | &#x2705;                |                        |                                                            |
|interfaces_gif.php                           | &#x2705;                |                        |                                                            |
|interfaces_gre_edit.php                      | &#x2705;                |                        |                                                            |
|interfaces_gre.php                           | &#x2705;                |                        |                                                            |
|interfaces_groups_edit.php                   |                         |                        |                                                            |
|interfaces_groups.php                        |                         |                        |                                                            |
|interfaces_lagg_edit.php                     | &#x2705;                |                        |                                                            |
|interfaces_lagg.php                          | &#x2705;                |                        |                                                            |
|interfaces.php                               |                         |                        |                                                            |
|interfaces_ppps_edit.php                     | &#x2705;                |                        |                                                            |
|interfaces_ppps.php                          | &#x2705;                |                        |                                                            |
|interfaces_qinq_edit.php                     |                         |                        |                                                            |
|interfaces_qinq.php                          | &#x2705;                |                        |                                                            |
|interfaces_vlan_edit.php                     | &#x2705;                |                        |                                                            |
|interfaces_vlan.php                          | &#x2705;                |                        |                                                            |
|interfaces_wireless_edit.php                 | &#x2705;                |                        |                                                            |
|interfaces_wireless.php                      | &#x2705;                |                        |                                                            |
|license.php                                  | &#x2705;                |                        |                                                            |
|load_balancer_monitor_edit.php               |                         |                        |                                                            |
|load_balancer_monitor.php                    |                         |                        |                                                            |
|load_balancer_pool_edit.php                  |                         |                        |                                                            |
|load_balancer_pool.php                       |                         |                        |                                                            |
|load_balancer_relay_action_edit.php          |                         |                        |                                                            |
|load_balancer_relay_action.php               |                         |                        |                                                            |
|load_balancer_relay_protocol_edit.php        |                         |                        |                                                            |
|load_balancer_relay_protocol.php             |                         |                        |                                                            |
|load_balancer_setting.php                    | &#x2705;                |                        |                                                            |
|load_balancer_virtual_server_edit.php        |                         |                        |                                                            |
|load_balancer_virtual_server.php             |                         |                        |                                                            |
|pkg_edit.php                                 |                         |                        |                                                            |
|pkg_mgr_installed.php                        | &#x2705;                |                        |                                                            |
|pkg_mgr_install.php                          | &#x2705;                |                        |                                                            |
|pkg_mgr.php                                  | &#x2705;                |                        |                                                            |
|pkg_mgr_settings.php                         | &#x2705;                |                        |                                                            |
|pkg.php                                      |                         |                        |                                                            |
|reboot.php                                   | &#x2705;                |                        |                                                            |
|restart_httpd.php                            |                         |                        |                                                            |
|services_captiveportal_filemanager.php       | &#x2705;                |                        |                                                            |
|services_captiveportal_hostname_edit.php     | &#x2705;                |                        |                                                            |
|services_captiveportal_hostname.php          | &#x2705;                |                        |                                                            |
|services_captiveportal_ip_edit.php           | &#x2705;                |                        |                                                            |
|services_captiveportal_ip.php                | &#x2705;                |                        |                                                            |
|services_captiveportal_mac_edit.php          | &#x2705;                |                        |                                                            |
|services_captiveportal_mac.php               | &#x2705;                |                        |                                                            |
|services_captiveportal.php                   |                         |                        |                                                            |
|services_captiveportal_vouchers_edit.php     | &#x2705;                |                        |                                                            |
|services_captiveportal_vouchers.php          | &#x2705;                |                        |                                                            |
|services_captiveportal_zones_edit.php        | &#x2705;                |                        |                                                            |
|services_captiveportal_zones.php             |                         |                        |                                                            |
|services_dhcp_edit.php                       | &#x2705;                |                        |                                                            |
|services_dhcp.php                            |                         |                        |                                                            |
|services_dhcp_relay.php                      | &#x2705;                |                        |                                                            |
|services_dhcpv6_edit.php                     | &#x2705;                |                        |                                                            |
|services_dhcpv6.php                          | &#x2705;                |                        |                                                            |
|services_dhcpv6_relay.php                    | &#x2705;                |                        |                                                            |
|services_dnsmasq_domainoverride_edit.php     | &#x2705;                |                        |                                                            |
|services_dnsmasq_edit.php                    | &#x2705;                |                        |                                                            |
|services_dnsmasq.php                         | &#x2705;                |                        |                                                            |
|services_dyndns_edit.php                     | &#x2705;                |                        |                                                            |
|services_dyndns.php                          | &#x2705;                |                        |                                                            |
|services_igmpproxy_edit.php                  | &#x2705;                |                        |                                                            |
|services_igmpproxy.php                       | &#x2705;                |                        |                                                            |
|services_ntpd_gps.php                        | &#x2705;                |                        |                                                            |
|services_ntpd.php                            | &#x2705;                |                        |                                                            |
|services_ntpd_pps.php                        | &#x2705;                |                        |                                                            |
|services_rfc2136_edit.php                    | &#x2705;                |                        |                                                            |
|services_rfc2136.php                         | &#x2705;                |                        |                                                            |
|services_router_advertisements.php           |                         |                        |                                                            |
|services_snmp.php                            | &#x2705;                |                        |                                                            |
|services_unbound_acls.php                    | &#x2705;                |                        |                                                            |
|services_unbound_advanced.php                | &#x2705;                |                        |                                                            |
|services_unbound_domainoverride_edit.php     | &#x2705;                |                        |                                                            |
|services_unbound_host_edit.php               | &#x2705;                |                        |                                                            |
|services_unbound.php                         | &#x2705;                |                        |                                                            |
|services_wol_edit.php                        | &#x2705;                |                        |                                                            |
|services_wol.php                             | &#x2705;                |                        |                                                            |
|stats.php                                    |                         |                        |                                                            |
|status_captiveportal_expire.php              | &#x2705;                |                        |                                                            |
|status_captiveportal.php                     | &#x2705;                |                        |                                                            |
|status_captiveportal_test.php                | &#x2705;                |                        |                                                            |
|status_captiveportal_voucher_rolls.php       | &#x2705;                |                        |                                                            |
|status_captiveportal_vouchers.php            | &#x2705;                |                        |                                                            |
|status_dhcp_leases.php                       | &#x2705;                |                        |                                                            |
|status_dhcpv6_leases.php                     | &#x2705;                |                        |                                                            |
|status_filter_reload.php                     | &#x2705;                |                        |                                                            |
|status_gateway_groups.php                    | &#x2705;                |                        |                                                            |
|status_gateways.php                          | &#x2705;                |                        |                                                            |
|status_graph_cpu.php                         | &#x2705;                |                        |                                                            |
|status_graph.php                             | &#x2705;                |                        |                                                            |
|status_interfaces.php                        | &#x2705;                |                        |                                                            |
|status_lb_pool.php                           | &#x2705;                |                        |                                                            |
|status_lb_vs.php                             | &#x2705;                |                        |                                                            |
|status_ntpd.php                              | &#x2705;                |                        |                                                            |
|status_openvpn.php                           |                         |                        |                                                            |
|status.php                                   | &#x2705;                |                        |                                                            |
|status_queues.php                            |                         |                        |                                                            |
|status_rrd_graph_img.php                     |                         |                        |                                                            |
|status_rrd_graph.php                         | &#x2705;                |                        |                                                            |
|status_rrd_graph_settings.php                | &#x2705;                |                        |                                                            |
|status_services.php                          | &#x2705;                |                        |                                                            |
|status_upnp.php                              | &#x2705;                |                        |                                                            |
|status_wireless.php                          | &#x2705;                |                        |                                                            |
|system_advanced_admin.php                    | &#x2705;                |                        |                                                            |
|system_advanced_firewall.php                 | &#x2705;                |                        |                                                            |
|system_advanced_misc.php                     | &#x2705;                |                        |                                                            |
|system_advanced_network.php                  | &#x2705;                |                        |                                                            |
|system_advanced_notifications.php            | &#x2705;                |                        |                                                            |
|system_advanced_sysctl.php                   |                         |                        |                                                            |
|system_authservers.php                       | &#x2705;                |                        |                                                            |
|system_camanager.php                         | &#x2705;                |                        |                                                            |
|system_certmanager.php                       | &#x2705;                |                        |                                                            |
|system_crlmanager.php                        |                         |                        |                                                            |
|system_firmware_auto.php                     | &#x2705;                |                        |                                                            |
|system_firmware_check.php                    | &#x2705;                |                        |                                                            |
|system_firmware.php                          | &#x2705;                |                        |                                                            |
|system_firmware_restorefullbackup.php        | &#x2705;                |                        |                                                            |
|system_firmware_settings.php                 | &#x2705;                |                        |                                                            |
|system_gateway_groups_edit.php               | &#x2705;                |                        |                                                            |
|system_gateway_groups.php                    | &#x2705;                |                        |                                                            |
|system_gateways_edit.php                     | &#x2705;                |                        |                                                            |
|system_gateways.php                          | &#x2705;                |                        |                                                            |
|system_groupmanager_addprivs.php             | &#x2705;                |                        |                                                            |
|system_groupmanager.php                      | &#x2705;                |                        |                                                            |
|system_hasync.php                            | &#x2705;                |                        |                                                            |
|system.php                                   | &#x2705;                |                        |                                                            |
|system_routes_edit.php                       | &#x2705;                |                        |                                                            |
|system_routes.php                            | &#x2705;                |                        |                                                            |
|system_usermanager_addprivs.php              | &#x2705;                |                        |                                                            |
|system_usermanager_passwordmg.php            | &#x2705;                |                        |                                                            |
|system_usermanager.php                       | &#x2705;                |                        |                                                            |
|system_usermanager_settings_ldapacpicker.php |                         |                        |                                                            |
|system_usermanager_settings.php              |                         |                        |                                                            |
|system_usermanager_settings_test.php         |                         |                        |                                                            |
|uploadconfig.php                             |                         |                        |                                                            |
|vpn_ipsec_keys_edit.php                      | &#x2705;                |                        |                                                            |
|vpn_ipsec_keys.php                           | &#x2705;                |                        |                                                            |
|vpn_ipsec_mobile.php                         | &#x2705;                |                        |                                                            |
|vpn_ipsec_phase1.php                         | &#x2705;                |                        |                                                            |
|vpn_ipsec_phase2.php                         | &#x2705;                |                        |                                                            |
|vpn_ipsec.php                                | &#x2705;                |                        |                                                            |
|vpn_ipsec_settings.php                       | &#x2705;                |                        |                                                            |
|vpn_l2tp.php                                 | &#x2705;                |                        |                                                            |
|vpn_l2tp_users_edit.php                      | &#x2705;                |                        |                                                            |
|vpn_l2tp_users.php                           | &#x2705;                |                        |                                                            |
|vpn_openvpn_client.php                       | &#x2705;                |                        |                                                            |
|vpn_openvpn_csc.php                          | &#x2705;                |                        |                                                            |
|vpn_openvpn_server.php                       | &#x2705;                |                        |                                                            |
|vpn_pppoe_edit.php                           | &#x2705;                |                        |                                                            |
|vpn_pppoe.php                                | &#x2705;                |                        |                                                            |
|vpn_pptp.php                                 |                         |                        |                                                            |
|vpn_pptp_users_edit.php                      |                         |                        |                                                            |
|vpn_pptp_users.php                           |                         |                        |                                                            |
|wizard.php                                   |                         |                        |                                                            |
|xmlrpc.php                                   |                         |                        |                                                            |
